@@ -21,7 +21,7 @@ use Dancer::Handler;
 use base 'Exporter';
 
 $AUTHORITY = 'SUKRIA';
-$VERSION   = '1.173_01';
+$VERSION   = '1.175_01';
 @EXPORT    = qw(
   any
   before
@@ -873,7 +873,7 @@ Here is an example of a route handler that will return a HashRef
     use Dancer;
     set serializer => 'JSON';
 
-    get '/user/:id'/ => sub {
+    get '/user/:id/' => sub {
         { foo => 42,
           number => 100234,
           list => [qw(one two three)],
@@ -990,6 +990,8 @@ terms as Perl itself.
 
 =head1 SEE ALSO
 
+Main Dancer web site: L<http://perldancer.org/>.
+
 The concept behind this module comes from the Sinatra ruby project,
 see L<http://www.sinatrarb.com/> for details.
 
