@@ -8,14 +8,19 @@ use Dancer::FileUtils 'read_file_content';
 
 sub init {
     my $self = shift;
-    $self->start_tag('<%') unless defined $self->start_tag;
-    $self->stop_tag('%>') unless defined $self->stop_tag;
+    my $settings = $self->config;
+
+    my $start = $settings->{'start_tag'} || '<%';
+    my $stop  = $settings->{'stop_tag'}  || '%>';
+
+    $self->start_tag($start) unless defined $self->start_tag;
+    $self->stop_tag($stop)   unless defined $self->stop_tag;
 }
 
 sub render($$$) {
     my ($self, $template, $tokens) = @_;
     my $content;
-    
+
     $content = _read_content_from_template($template);
     $content = $self->parse_branches($content, $tokens);
 
@@ -27,22 +32,22 @@ sub parse_branches {
     my ($start, $stop) = ($self->start_tag, $self->stop_tag);
 
     my @buffer;
-    my $prefix = "";
-    my $should_bufferize = 1;
-    my $opened_tag = 0;
+    my $prefix             = "";
+    my $should_bufferize   = 1;
+    my $opened_tag         = 0;
     my $bufferize_if_token = 0;
-    $content =~ s/${start}(\S)/${start} $1/sg; 
-    $content =~ s/(\S)${stop}/$1 ${stop}/sg; 
-    
+    $content =~ s/\Q${start}\E(\S)/${start} $1/sg;
+    $content =~ s/(\S)\Q${stop}\E/$1 ${stop}/sg;
+
     foreach my $word (split / /, $content) {
-        if ($word =~ /(.*)$start/s) {
+        if ($word =~ /(.*)\Q$start\E/s) {
             my $junk = $1;
             $opened_tag = 1;
             if (defined($junk) && length($junk)) {
                 $prefix = $junk;
             }
         }
-        elsif ($word =~ /$stop(.*)/s) {
+        elsif ($word =~ /\Q$stop\E(.*)/s) {
             my $junk = $1;
             if (defined($junk) && length($junk)) {
                 if (@buffer) {
@@ -54,11 +59,11 @@ sub parse_branches {
             }
             $opened_tag = 0;
         }
-        elsif ($word eq 'if' && $opened_tag ) {
+        elsif ($word eq 'if' && $opened_tag) {
             $bufferize_if_token = 1;
             next;
         }
-        elsif ($word eq 'else' && $opened_tag ) {
+        elsif ($word eq 'else' && $opened_tag) {
             $should_bufferize = !$should_bufferize;
             next;
         }
@@ -72,11 +77,16 @@ sub parse_branches {
             next;
         }
         elsif ($opened_tag) {
-            push @buffer, ($prefix . _interpolate_value( _find_value_from_token_name($word, $tokens)));
+            push @buffer,
+              ( $prefix
+                  . _interpolate_value(
+                    _find_value_from_token_name($word, $tokens)
+                  )
+              );
             $prefix = "";
         }
-        elsif($should_bufferize) {
-            push @buffer, $prefix.$word;
+        elsif ($should_bufferize) {
+            push @buffer, $prefix . $word;
             $prefix = "";
         }
     }
@@ -84,20 +94,6 @@ sub parse_branches {
     return join " ", @buffer;
 }
 
-# this is pure variable interpolation, without branch conditions
-sub interpolate {
-    my ($self, $content, $tokens) = @_;
-    my ($start, $stop) = ($self->start_tag, $self->stop_tag);
-    
-    while ($content =~ /${start}\s*(\S+)\s*${stop}/) {
-        my $key = $1;
-        my $value = _find_value_from_token_name($key, $tokens);
-        $value    = _interpolate_value($value); 
-        $content  =~ s/${start}\s*(\S+)\s*${stop}/$value/;
-    }
-    return $content;
-}
-
 # private
 
 sub _read_content_from_template {
@@ -109,10 +105,10 @@ sub _read_content_from_template {
     }
     else {
         die "'$template' is not a regular file"
-            unless -f $template;
+          unless -f $template;
         $content = read_file_content($template);
-        die "unable to read content for file $template" 
-            if not defined $content;
+        die "unable to read content for file $template"
+          if not defined $content;
     }
     return $content;
 }
